[Erp5-report] r26717 - /erp5/trunk/products/ERP5/tests/testBPMCore.py

nobody at svn.erp5.org nobody at svn.erp5.org
Wed Apr 29 17:07:05 CEST 2009


Author: luke
Date: Wed Apr 29 17:07:05 2009
New Revision: 26717

URL: http://svn.erp5.org?rev=26717&view=rev
Log:
 - next test to TODO

Modified:
    erp5/trunk/products/ERP5/tests/testBPMCore.py

Modified: erp5/trunk/products/ERP5/tests/testBPMCore.py
URL: http://svn.erp5.org/erp5/trunk/products/ERP5/tests/testBPMCore.py?rev=26717&r1=26716&r2=26717&view=diff
==============================================================================
--- erp5/trunk/products/ERP5/tests/testBPMCore.py [utf8] (original)
+++ erp5/trunk/products/ERP5/tests/testBPMCore.py [utf8] Wed Apr 29 17:07:05 2009
@@ -1404,11 +1404,15 @@
     sequence_list.play(self)
 
   def test_TradeModelRuleSimulationBuildInvoiceNewTradeConditionDivergencyAndSolving(self):
-    """Check that after changing trade model invoice is properly diverged and it is possible to solve"""
+    """Check that after changing trade condition invoice is properly diverged and it is possible to solve"""
     raise NotImplementedError('TODO')
 
+  def test_TradeModelRuleSimulationBuildInvoiceNewInvoiceLineSupport(self):
+    """Check how is supported addition of invoice line to invoice build from order"""
+    raise NotImplementedError('TODO')
+
   def test_TradeModelRuleSimulationBuildInvoiceInvoiceLineModifyDivergencyAndSolving(self):
     """Check that after changing trade model invoice is properly diverged and it is possible to solve"""
     sequence_list = SequenceList()
     sequence_string = self.trade_model_rule_simulation_common_string
     sequence_string += """
@@ -1404,11 +1404,15 @@
   def test_TradeModelRuleSimulationBuildInvoiceInvoiceLineModifyDivergencyAndSolving(self):
-    """Check that after changing trade model invoice is properly diverged and it is possible to solve"""
+    """Check that after changing invoice line invoice is properly diverged and it is possible to solve"""
     sequence_list = SequenceList()
     sequence_string = self.trade_model_rule_simulation_common_string




More information about the Erp5-report mailing list